# DatasetColumn

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**order** | **float** | The order that the column comes in, 0-based. (The first column is 0, second is 1, etc.) | [optional] 
**name** | **str** | The column name | [optional] 
**type** | **str** | The type of all of the fields in the column. Please see the data types on https://github.com/Kaggle/kaggle-api/wiki/Dataset-Metadata | [optional] 
**original_type** | **str** | Used to store the original type of the column, which will be converted to Kaggle&#39;s types. For example, an &#x60;originalType&#x60; of &#x60;\&quot;integer\&quot;&#x60; would convert to a &#x60;type&#x60; of &#x60;\&quot;numeric\&quot;&#x60; | [optional] 
**description** | **str** | The description of the column | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


